## About
This is the implementation of Counterpropagation Models based on [Prototorch](https://github.com/si-cim/prototorch) by [SICIM](https://www.institute.hs-mittweida.de/webs/sicim/).

## How to install and use

To install use:
```
pip install counterprop-prototorch
```
This will install the package, as well as the needed additions.

For a use-case scenario please have a look a the __example.py__ file.

## Contact
bugs, fixes, ideas etc. can be send to [trebuhcsynnor@gmail.com](mailto:trebuhcsynnor@gmail.com) 